@@ -6,6 +6,27 @@ from ...publish import PublishGPT
 from .command_manager import Commands
 from .base_command import BaseCommand
 
+@Commands.register('.buffer')
+class BufferCommand(BaseCommand):
+
+  aliases = [ '.b' ]
+  # help = 'Opens the current message in the text editor specified by $EDITOR.'
+  shortcut = [ 'C-x', 'C-b' ]
+  erase_input = True
+
+  def run(self):
+    name = self.cmd_args[0] if len(self.cmd_args) > 0 else ''
+    (title, buffer, file_type) = self.repl.mode.get_buffer(name)
+    self.banner(name=title)
+
+    value = open_in_editor(self.repl.prompt.session, content=buffer, extension=file_type)
+    self.repl.mode.set_buffer(name, value)
+
+    printer.clear(2)
+    printer.print(self.repl.mode.get_buffer(name)[1])
+
+    return ''
+
 @Commands.register('.clear')
 class ClearCommand(BaseCommand):
 
@@ -15,7 +36,7 @@ class ClearCommand(BaseCommand):
   erase_input = True
 
   def run(self):
-    printer.clear(1)
+    printer.clear(2)
     self.action('prompt')
 
 @Commands.register('.copy')
@@ -122,10 +143,9 @@ class RedoCommand(BaseCommand):
     if len(history) < 2:
       return 'No message to redo'
 
-    self.repl.mode.rollback()
-    self.repl.mode.rollback()
+    self.repl.mode.rollback_n(2)
     last_message = history[-2].text
-    self.repl.thread.rollback(2)
+    self.repl.thread.rollback_n(2)
 
     self.set_text(last_message)
     self.action('continue')
@@ -144,10 +164,9 @@ class UndoCommand(BaseCommand):
     if len(history) < 2:
       return 'No message to undo'
 
-    self.repl.mode.rollback()
-    self.repl.mode.rollback()
+    self.repl.mode.rollback_n(2)
     last_message = history[-2].text
-    self.repl.thread.rollback(2)
+    self.repl.thread.rollback_n(2)
 
     self.repl.auto_fills += [ last_message ]
     self.action('break')
@@ -231,3 +250,13 @@ class SetCommand(BaseCommand):
       setattr(self.repl.mode, key, val)
       printer.print_markdown(f'**{key}** updated')
     return ''
+
+
+@Commands.register('.stats')
+class SetCommand(BaseCommand):
+
+  aliases = [ '.st' ]
+
+  def run(self):
+    self.banner()
+    return self.repl.mode.stats()
