@@ -1,10 +1,20 @@
 import os, re, pyperclip
 from itertools import chain
+from collections.abc import Iterable
 
 def peek(gen):
   first = next(gen)
   return ( chain([ first ], gen), first )
 
+def make_iter(x):
+  if isinstance(x, str) or not isinstance(x, Iterable):
+    return iter([ x ])
+  else:
+    return x
+
+def expand_path(*args):
+  return os.path.abspath(os.path.expanduser(os.path.join(*args)))
+
 class set_env:
 
   def __init__(self, name, value):
